darkhistory.physics.peebles_C — DarkHistory documentation

# darkhistory.physics.peebles_C

`darkhistory.physics.` `peebles_C`(xHII, rs)

  Hydrogen Peebles C coefficient.

  This is the ratio of the total rate for transitions from n = 2 to the ground state to the total rate of all transitions, including ionization.

  Parameters: | xHII : float The ionization fraction nHII/nH. rs : float The redshift in 1+z.
  Returns: | float The Peebles C factor.

#### Previous topic

darkhistory.physics.beta_ion

#### Next topic

darkhistory.physics.C_He

### This Page

Show Source